@@ -120,8 +120,8 @@ class PrintInspections(AbstractCommandLineInterface):
         """
 
         detail = {"input_data_index": input_data_index}
-        inspectins, _ = self.service.api.get_inspections(project_id, task_id, input_data_id)
-        return [self.visualize.add_properties_to_inspection(e, detail) for e in inspectins]
+        inspections, _ = self.service.api.get_inspections(project_id, task_id, input_data_id)
+        return [self.visualize.add_properties_to_inspection(e, detail) for e in inspections]
 
     def get_inspections(
         self, project_id: str, task_id_list: List[str], filter_inspection: Optional[FilterInspectionFunc] = None
@@ -212,10 +212,10 @@ def main(args):
 def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "list"
 
-    subcommand_help = "検査コメント一覧を出力します。"
+    subcommand_help = "[DEPRECATED] 検査コメント一覧を出力します。"
 
-    description = "検査コメント一覧を出力します。"
+    description = "[DEPRECATED] 検査コメント一覧を出力します。\n2022/12/01以降に廃止する予定です。替わりに ``annofabcli comment list`` コマンドを利用してください。"
 
-    parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description)
+    parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=description)
     parse_args(parser)
     return parser
