@@ -1,7 +1,6 @@
 import logging
 from typing import Any, Dict, List, Optional
 
-import dateutil
 import more_itertools
 import pandas
 from annofabapi.models import Task, TaskHistory, TaskPhase
@@ -140,31 +139,9 @@ class Table:
         タスク履歴関係の情報を設定する
         """
 
-        def diff_days(ended_key: str, started_key: str) -> Optional[float]:
-            if task[ended_key] is not None and task[started_key] is not None:
-                delta = dateutil.parser.parse(task[ended_key]) - dateutil.parser.parse(task[started_key])
-                return delta.total_seconds() / 3600 / 24
-            else:
-                return None
-
         task["worktime_hour"] = sum(
-            [annofabcli.utils.isoduration_to_hour(e["accumulated_labor_time_milliseconds"]) for e in task_histories]
-        )
-
-        # APIで取得した 'number_of_rejections' は非推奨で、number_of_rejections_by_inspection/acceptanceと矛盾する場合があるので、書き換える
-        task["number_of_rejections"] = (
-            task["number_of_rejections_by_inspection"] + task["number_of_rejections_by_acceptance"]
-        )
-
-        task["diff_days_to_first_inspection_started"] = diff_days(
-            "first_inspection_started_datetime", "first_annotation_started_datetime"
-        )
-        task["diff_days_to_first_acceptance_started"] = diff_days(
-            "first_acceptance_started_datetime", "first_annotation_started_datetime"
-        )
-
-        task["diff_days_to_first_acceptance_completed"] = diff_days(
-            "first_acceptance_completed_datetime", "first_annotation_started_datetime"
+            annofabcli.common.utils.isoduration_to_hour(e["accumulated_labor_time_milliseconds"])
+            for e in task_histories
         )
 
         return task
@@ -194,19 +171,30 @@ class Table:
                 history["user_id"] = self._get_user_id(account_id)
                 history["username"] = self._get_username(account_id)
                 history["biography"] = self._get_biography(account_id)
-                history["worktime_hour"] = annofabcli.utils.isoduration_to_hour(
+                history["worktime_hour"] = annofabcli.common.utils.isoduration_to_hour(
                     history["accumulated_labor_time_milliseconds"]
                 )
                 # task statusがあると分析しやすいので追加する
                 history["task_status"] = task["status"]
                 all_task_history_list.append(history)
 
-        df = pandas.DataFrame(all_task_history_list)
+        df = pandas.DataFrame(
+            all_task_history_list,
+            columns=[
+                "project_id",
+                "task_id",
+                "phase",
+                "phase_stage",
+                "account_id",
+                "user_id",
+                "username",
+                "biography",
+                "worktime_hour",
+            ],
+        )
         if len(df) == 0:
             logger.warning("タスク履歴の件数が0件です。")
-            return pandas.DataFrame()
-        else:
-            return df
+        return df
 
     def create_task_df(self) -> pandas.DataFrame:
         """
@@ -223,7 +211,6 @@ class Table:
         adding_obj = AddingAdditionalInfoToTask(self.annofab_service, project_id=self.project_id)
 
         for task in tasks:
-
             adding_obj.add_additional_info_to_task(task)
 
             task_id = task["task_id"]
@@ -246,7 +233,43 @@ class Table:
             return df
         else:
             logger.warning(f"タスク一覧が0件です。")
-            return pandas.DataFrame()
+
+            numeric_columns = [
+                "worktime_hour",
+                "annotation_worktime_hour",
+                "inspection_worktime_hour",
+                "acceptance_worktime_hour",
+                "input_data_count",
+                "annotation_count",
+                "inspection_comment_count",
+                "number_of_rejections_by_inspection",
+                "number_of_rejections_by_acceptance",
+            ]
+            string_columns = [
+                "project_id",
+                "task_id",
+                "phase",
+                "phase_stage",
+                "status",
+                "first_annotation_user_id",
+                "first_annotation_username",
+                "first_annotation_worktime_hour",
+                "first_annotation_started_datetime",
+                "first_inspection_user_id",
+                "first_inspection_username",
+                "first_inspection_worktime_hour",
+                "first_inspection_started_datetime",
+                "first_acceptance_user_id",
+                "first_acceptance_username",
+                "first_acceptance_worktime_hour",
+                "first_acceptance_started_datetime",
+                "first_acceptance_completed_datetime",
+            ]
+            boolean_columns = ["inspection_is_skipped", "acceptance_is_skipped"]
+            columns = string_columns + numeric_columns + boolean_columns
+            dtypes = {e: "float64" for e in numeric_columns}
+            dtypes.update({e: "boolean" for e in boolean_columns})
+            return pandas.DataFrame([], columns=columns).astype(dtypes)
 
     @staticmethod
     def create_annotation_count_ratio_df(
@@ -266,7 +289,7 @@ class Table:
                 "annotation_count": row["annotation_count"],
                 "input_data_count": row["input_data_count"],
                 "inspection_comment_count": row["inspection_comment_count"],
-                "rejected_count": row["number_of_rejections"],
+                "rejected_count": row["number_of_rejections_by_inspection"] + row["number_of_rejections_by_acceptance"],
             }
             for _, row in task_df.iterrows()
         }
@@ -316,9 +339,9 @@ class Table:
                 ]
             )
 
-        group_obj["worktime_ratio_by_task"] = group_obj.groupby(level=["task_id", "phase", "phase_stage"]).apply(
-            lambda e: e / float(e.sum())
-        )
+        group_obj["worktime_ratio_by_task"] = group_obj.groupby(
+            level=["task_id", "phase", "phase_stage"], group_keys=False
+        ).apply(lambda e: e / float(e.sum()))
         group_obj["annotation_count"] = group_obj.apply(get_annotation_count, axis="columns")
         group_obj["input_data_count"] = group_obj.apply(get_input_data_count, axis="columns")
         group_obj["pointed_out_inspection_comment_count"] = group_obj.apply(
