@@ -48,16 +48,41 @@ class UserPerformance:
     PLOT_HEIGHT = 800
 
     def __init__(self, df: pandas.DataFrame):
-        self.df = df
         self.phase_list = self.get_phase_list(df.columns)
+        self.df = df
+
+    def is_empty(self) -> bool:
+        """
+        空のデータフレームを持つかどうかを返します。
+
+        Returns:
+            空のデータフレームを持つかどうか
+        """
+        return len(self.df) == 0
 
     @staticmethod
     def _add_ratio_column_for_productivity_per_user(df: pandas.DataFrame, phase_list: list[str]):
+        """
+        ユーザーの生産性に関する列を、DataFrameに追加します。
+        """
         for phase in phase_list:
+
+            def get_monitored_worktime_ratio(row: pandas.Series) -> float:
+                """
+
+                計測作業時間の合計値が0により、monitored_worktime_ratioはnanになる場合は、教師付の実績作業時間を実績作業時間の合計値になるようなmonitored_worktime_ratioに変更する
+                """
+                if row[("monitored_worktime_hour", "sum")] == 0:
+                    if phase == TaskPhase.ANNOTATION.value:
+                        return 1
+                    else:
+                        return 0
+                else:
+                    return row[("monitored_worktime_hour", phase)] / row[("monitored_worktime_hour", "sum")]
+
             # Annofab時間の比率
-            df[("monitored_worktime_ratio", phase)] = (
-                df[("monitored_worktime_hour", phase)] / df[("monitored_worktime_hour", "sum")]
-            )
+            df[("monitored_worktime_ratio", phase)] = df.apply(get_monitored_worktime_ratio, axis=1)
+
             # Annofab時間の比率から、Annowork時間を予測する
             df[("actual_worktime_hour", phase)] = (
                 df[("actual_worktime_hour", "sum")] * df[("monitored_worktime_ratio", phase)]
@@ -105,6 +130,30 @@ class UserPerformance:
         df = read_multiheader_csv(str(csv_file))
         return cls(df)
 
+    @classmethod
+    def empty(cls) -> UserPerformance:
+        """空のデータフレームを持つインスタンスを生成します。"""
+
+        df_dtype: dict[tuple[str, str], str] = {
+            ("user_id", ""): "string",
+            ("username", ""): "string",
+            ("biography", ""): "string",
+            ("last_working_date", ""): "string",
+            # phaseがinspection, acceptanceの列は出力されない可能性があるので、絶対出力される"sum", "annotation"の列のみ定義する
+            ("monitored_worktime_hour", "annotation"): "float64",
+            ("monitored_worktime_hour", "sum"): "float64",
+            ("task_count", "annotation"): "float64",
+            ("input_data_count", "annotation"): "float64",
+            ("annotation_count", "annotation"): "float64",
+            ("actual_worktime_hour", "sum"): "float64",
+            ("actual_worktime_hour", "annotation"): "float64",
+            ("pointed_out_inspection_comment_count", "annotation"): "float64",
+            ("rejected_count", "annotation"): "float64",
+        }
+
+        df = pandas.DataFrame(columns=pandas.MultiIndex.from_tuples(df_dtype.keys())).astype(df_dtype)
+        return cls(df)
+
     def actual_worktime_exists(self) -> bool:
         """実績作業時間が入力されているか否か"""
         return self.df[("actual_worktime_hour", "sum")].sum() > 0
@@ -114,6 +163,7 @@ class UserPerformance:
         cls,
         df_task_history: pandas.DataFrame,
         df_worktime_ratio: pandas.DataFrame,
+        df_user: pandas.DataFrame,
         df_labor: Optional[pandas.DataFrame] = None,
     ) -> UserPerformance:
         """
@@ -136,6 +186,7 @@ class UserPerformance:
             for phase in TaskPhase:
                 if phase.value in columns:
                     phase_list.append(phase.value)
+
             return phase_list
 
         df_agg_task_history = df_task_history.pivot_table(
@@ -151,14 +202,20 @@ class UserPerformance:
                 df_agg_labor["last_working_date"] = df_tmp
             else:
                 df_agg_labor["last_working_date"] = numpy.nan
-            df = df_agg_task_history.join(df_agg_labor)
+
+            if len(df_agg_task_history) > 0:
+                df = df_agg_task_history.join(df_agg_labor)
+            else:
+                # Annofabで作業していないけど実績がある状態
+                df = df_agg_labor.copy()
+                # 教師付作業時間を0にする
+                df["annotation"] = 0
         else:
             df = df_agg_task_history
             df["actual_worktime_hour"] = 0
             df["last_working_date"] = None
 
         phase_list = get_phase_list(list(df.columns))
-
         df = df[["actual_worktime_hour", "last_working_date"] + phase_list].copy()
         df.columns = pandas.MultiIndex.from_tuples(
             [("actual_worktime_hour", "sum"), ("last_working_date", "")]
@@ -169,21 +226,36 @@ class UserPerformance:
             axis=1
         )
 
-        df_agg_production = df_worktime_ratio.pivot_table(
-            values=[
-                "worktime_ratio_by_task",
-                "input_data_count",
-                "annotation_count",
-                "pointed_out_inspection_comment_count",
-                "rejected_count",
-            ],
-            columns="phase",
-            index="account_id",
-            aggfunc=numpy.sum,
-        ).fillna(0)
+        if len(df_worktime_ratio) > 0:
+            df_agg_production = df_worktime_ratio.pivot_table(
+                values=[
+                    "worktime_ratio_by_task",
+                    "input_data_count",
+                    "annotation_count",
+                    "pointed_out_inspection_comment_count",
+                    "rejected_count",
+                ],
+                columns="phase",
+                index="account_id",
+                aggfunc=numpy.sum,
+            ).fillna(0)
+        else:
+            df_agg_production = pandas.DataFrame(
+                columns=pandas.MultiIndex.from_tuples(
+                    [
+                        ("worktime_ratio_by_task", "annotation"),
+                        ("input_data_count", "annotation"),
+                        ("annotation_count", "annotation"),
+                        ("pointed_out_inspection_comment_count", "annotation"),
+                        ("rejected_count", "annotation"),
+                    ]
+                )
+            )
 
         df_agg_production.rename(columns={"worktime_ratio_by_task": "task_count"}, inplace=True)
         df = df.join(df_agg_production)
+        # 数値列のNaNを0にする(df_agg_productionが0件のときの対応)
+        df.fillna(0, inplace=True)
 
         # 比例関係の列を計算して追加する
         cls._add_ratio_column_for_productivity_per_user(df, phase_list=phase_list)
@@ -198,13 +270,28 @@ class UserPerformance:
         df = df.drop(dropped_column, axis=1)
 
         # ユーザ情報を取得
-        df_user = df_task_history.groupby("account_id").first()[["user_id", "username", "biography"]]
-        df_user.columns = pandas.MultiIndex.from_tuples([("user_id", ""), ("username", ""), ("biography", "")])
-        df = df.join(df_user)
+        tmp_df_user = df_user.set_index("account_id")[["user_id", "username", "biography"]]
+        tmp_df_user.columns = pandas.MultiIndex.from_tuples([("user_id", ""), ("username", ""), ("biography", "")])
+        df = df.join(tmp_df_user)
         return cls(df)
 
     @classmethod
-    def merge(cls, obj1: UserPerformance, obj2: UserPerformance) -> UserPerformance:
+    def _convert_column_dtypes(cls, df: pandas.DataFrame) -> pandas.DataFrame:
+        """
+        引数`df`の列の型を正しい型に変換する。
+        """
+
+        columns = set(df.columns)
+        # 列ヘッダに相当する列名
+        basic_columns = [("user_id", ""), ("username", ""), ("biography", ""), ("last_working_date", "")]
+
+        value_columns = columns - set(basic_columns)
+        dtypes = {col: "string" for col in basic_columns}
+        dtypes.update({col: "float64" for col in value_columns})
+        return df.astype(dtypes)
+
+    @staticmethod
+    def merge(obj1: UserPerformance, obj2: UserPerformance) -> UserPerformance:
         def max_last_working_date(date1, date2):
             if not isinstance(date1, str) and numpy.isnan(date1):
                 date1 = ""
@@ -221,6 +308,7 @@ class UserPerformance:
             sum_row = row1.drop(labels=string_column_list, level=0).fillna(0) + row2.drop(
                 labels=string_column_list, level=0
             ).fillna(0)
+
             sum_row.loc["username", ""] = row1.loc["username", ""]
             sum_row.loc["biography", ""] = row1.loc["biography", ""]
             sum_row.loc["last_working_date", ""] = max_last_working_date(
@@ -230,6 +318,7 @@ class UserPerformance:
 
         df1 = obj1.df
         df2 = obj2.df
+
         user_id_set = set(df1["user_id"]) | set(df2["user_id"])
         sum_df = df1.set_index("user_id").copy()
         added_df = df2.set_index("user_id")
@@ -237,16 +326,20 @@ class UserPerformance:
         for user_id in user_id_set:
             if user_id not in added_df.index:
                 continue
+
             if user_id in sum_df.index:
                 sum_df.loc[user_id] = merge_row(sum_df.loc[user_id], added_df.loc[user_id])
             else:
                 sum_df.loc[user_id] = added_df.loc[user_id]
 
-        phase_list = cls.get_phase_list(list(sum_df["monitored_worktime_hour"].columns))
-        cls._add_ratio_column_for_productivity_per_user(sum_df, phase_list=phase_list)
         sum_df.reset_index(inplace=True)
+        # DataFrameを一旦Seriesに変換することで、列の型情報がすべてobjectになるので、再度正しい列の型に変換する
+        sum_df = UserPerformance._convert_column_dtypes(sum_df)
+
+        phase_list = UserPerformance.get_phase_list(list(sum_df["monitored_worktime_hour"].columns))
+        UserPerformance._add_ratio_column_for_productivity_per_user(sum_df, phase_list=phase_list)
         sum_df.sort_values(["user_id"], inplace=True)
-        return cls(sum_df)
+        return UserPerformance(sum_df)
 
     def _validate_df_for_output(self, output_file: Path) -> bool:
         if len(self.df) == 0:
@@ -382,6 +475,57 @@ class UserPerformance:
             legend = fig.legend[0]
             fig.add_layout(legend, "left")
 
+    @staticmethod
+    def _add_ratio_key_for_whole_productivity(series: pandas.Series, phase_list: list[str]):
+        """
+        プロジェクト全体の生産性に関するkeyを、pandas.Seriesに追加します。
+        """
+        # ゼロ割の警告を無視する
+        with numpy.errstate(divide="ignore", invalid="ignore"):
+            for phase in phase_list:
+                # Annofab時間の比率を算出
+                # 計測作業時間の合計値が0により、monitored_worktime_ratioはnanになる場合は、教師付の実績作業時間を実績作業時間の合計値になるようなmonitored_worktime_ratioに変更する
+                if series[("monitored_worktime_hour", "sum")] == 0:
+                    if phase == TaskPhase.ANNOTATION.value:
+                        series[("monitored_worktime_ratio", phase)] = 1
+                    else:
+                        series[("monitored_worktime_ratio", phase)] = 0
+                else:
+                    series[("monitored_worktime_ratio", phase)] = (
+                        series[("monitored_worktime_hour", phase)] / series[("monitored_worktime_hour", "sum")]
+                    )
+
+                # Annofab時間の比率から、Annowork時間を予測する
+                series[("actual_worktime_hour", phase)] = (
+                    series[("actual_worktime_hour", "sum")] * series[("monitored_worktime_ratio", phase)]
+                )
+
+                # 生産性を算出
+                series[("monitored_worktime_hour/input_data_count", phase)] = (
+                    series[("monitored_worktime_hour", phase)] / series[("input_data_count", phase)]
+                )
+                series[("actual_worktime_hour/input_data_count", phase)] = (
+                    series[("actual_worktime_hour", phase)] / series[("input_data_count", phase)]
+                )
+
+                series[("monitored_worktime_hour/annotation_count", phase)] = (
+                    series[("monitored_worktime_hour", phase)] / series[("annotation_count", phase)]
+                )
+                series[("actual_worktime_hour/annotation_count", phase)] = (
+                    series[("actual_worktime_hour", phase)] / series[("annotation_count", phase)]
+                )
+
+            phase = TaskPhase.ANNOTATION.value
+            series[("pointed_out_inspection_comment_count/annotation_count", phase)] = (
+                series[("pointed_out_inspection_comment_count", phase)] / series[("annotation_count", phase)]
+            )
+            series[("pointed_out_inspection_comment_count/input_data_count", phase)] = (
+                series[("pointed_out_inspection_comment_count", phase)] / series[("input_data_count", phase)]
+            )
+            series[("rejected_count/task_count", phase)] = (
+                series[("rejected_count", phase)] / series[("task_count", phase)]
+            )
+
     def get_summary(self) -> pandas.Series:
         """
         全体の生産性と品質が格納された pandas.Series を取得する。
@@ -397,8 +541,7 @@ class UserPerformance:
             "rejected_count",
         ]
         sum_series = self.df[columns_for_sum].sum()
-
-        self._add_ratio_column_for_productivity_per_user(sum_series, phase_list=self.phase_list)
+        self._add_ratio_key_for_whole_productivity(sum_series, phase_list=self.phase_list)
 
         # 作業している人数をカウントする
         for phase in self.phase_list:
@@ -795,6 +938,11 @@ class WholePerformance:
         series = user_performance.get_summary()
         return cls(series)
 
+    @classmethod
+    def empty(cls) -> WholePerformance:
+        """空のデータフレームを持つインスタンスを生成します。"""
+        return cls.from_user_performance(UserPerformance.empty())
+
     @classmethod
     def from_csv(cls, csv_file: Path) -> WholePerformance:
         """CSVファイルからインスタンスを生成します。"""
