@@ -7,9 +7,9 @@ import pandas
 from annofabapi.models import Task
 
 import annofabcli
-from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import AbstractCommandLineInterface, ArgumentParser, build_annofabapi_resource_and_login
 from annofabcli.common.enums import FormatArgument
+from annofabcli.common.facade import AnnofabApiFacade
 from annofabcli.common.utils import get_columns_with_priority
 from annofabcli.common.visualize import AddProps
 
@@ -23,11 +23,6 @@ class ListTasksMain:
         self.project_id = project_id
         self.visualize = AddProps(self.service, project_id)
 
-    @annofabcli.utils.allow_404_error
-    def get_task(self, project_id: str, task_id: str) -> Task:
-        task, _ = self.service.api.get_task(project_id, task_id)
-        return task
-
     def get_task_list_from_task_id(self, project_id: str, task_id_list: List[str]) -> List[Task]:
         task_list = []
         logger.debug(f"{len(task_id_list)}件のタスクを取得します。")
@@ -35,7 +30,7 @@ class ListTasksMain:
             if (index + 1) % 100 == 0:
                 logger.debug(f"{index+1} 件のタスクを取得します。")
 
-            task = self.get_task(project_id, task_id)
+            task = self.service.wrapper.get_task_or_none(project_id, task_id)
             if task is not None:
                 task_list.append(self.visualize.add_properties_to_task(task))
             else:
@@ -165,25 +160,24 @@ class ListTasks(AbstractCommandLineInterface):
         "status",
         "started_datetime",
         "updated_datetime",
+        "operation_updated_datetime",
+        "account_id",
         "user_id",
         "username",
         "worktime_hour",
-        "metadata",
         "number_of_rejections_by_inspection",
         "number_of_rejections_by_acceptance",
+        "metadata",
+        "sampling",
+        "input_data_count",
+        "input_data_id_list",
     ]
 
     def main(self):
         args = self.args
 
-        task_id_list = annofabcli.common.cli.get_list_from_args(args.task_id)
-        if len(task_id_list) == 0:
-            task_id_list = None
-
-        user_id_list = annofabcli.common.cli.get_list_from_args(args.user_id)
-        if len(user_id_list) == 0:
-            user_id_list = None
-
+        task_id_list = annofabcli.common.cli.get_list_from_args(args.task_id) if args.task_id is not None else None
+        user_id_list = annofabcli.common.cli.get_list_from_args(args.user_id) if args.user_id is not None else None
         task_query = annofabcli.common.cli.get_json_from_args(args.task_query)
 
         project_id = args.project_id
